# Ion Detective

This library provides functionalities to assist students to perform qualitative chemical analysis in Python.

Usually, this analysis is performed in the wet lab, in which students are provided a sample probe that contains 
a random composition of anions or cations, respectively. To determine the composition of their sample, students
have to perform a variety of chemical detection reactions.

This library tries to simulate this experience in a virtual, text-based way and contains real workflows for the
reactions.


# Installation

```pip install ion_detective```
